load ../lib/common

setup() {
	libretools_common_per_test_setup

	install -Dm644 /dev/stdin "$XDG_CONFIG_HOME/libretools/libredbdiff.conf" <<-'eot'
		statedir="$PWD"
		mirror_prbl='https://repo.parabola.nu/$repo/os/$arch'
		mirror_arch='https://mirrors.kernel.org/archlinux/$repo/os/$arch'
		repos=(libre)
	eot
}

# bats test_tags=locale-es
@test "libredbdiff follows cli conventions" {
	assert_follows_cli_conventions libredbdiff
	assert_shows_usage libredbdiff --help --noupdate
	assert_shows_usage libredbdiff --noupdate --help
}

@test "libredbdiff handles packages with multiple provides explicit" {
	cd fixtures/libredbdiff/statedir

	libredbdiff -n libre >$tmpdir/stdout 2>$tmpdir/stderr

	assert_file_empty $tmpdir/stderr
	diff -w ../expected-explicit.txt $tmpdir/stdout
}

@test "libredbdiff handles packages with multiple provides implicit" {
	cd fixtures/libredbdiff/statedir

	libredbdiff -n >$tmpdir/stdout 2>$tmpdir/stderr

	assert_file_empty $tmpdir/stderr
	diff -w ../expected-implicit.txt $tmpdir/stdout
}

@test "libredbdiff fails on bad repo args" {
	cd fixtures/libredbdiff/statedir

	libredbdiff -n bogus >$tmpdir/stdout 2>$tmpdir/stderr || status=$?

	[[ $status != 0 ]]
	assert_file_empty $tmpdir/stdout
	assert_file_not_empty $tmpdir/stderr
}
