load ../lib/common

# bats test_tags=locale-es
@test "librexgettext follows cli conventions and fails with 0 args" {
	assert_follows_cli_conventions librexgettext
	assert_fails_with_errusage librexgettext
}

passcase() {
	librexgettext fixtures/librexgettext/$BATS_TEST_NAME.sh >$tmpdir/actual.pot 2>$tmpdir/stderr
	assert_file_empty $tmpdir/stderr
	diff -u fixtures/librexgettext/$BATS_TEST_NAME.pot $tmpdir/actual.pot
}

@test "librexgettext handles multiple skipped flags" { passcase; }
@test "librexgettext handles zero flags" { passcase; }
@test "librexgettext handles librefetch flags" { passcase; }

@test "librexgettext fails on missing final flag description" {
	librexgettext fixtures/librexgettext/$BATS_TEST_NAME.sh >/dev/null 2>$tmpdir/stderr || status=$?

	[[ $status != 0 ]]
	[[ "$(sed 1q $tmpdir/stderr)" == "fixtures/librexgettext/$BATS_TEST_NAME.sh:5:"* ]]
}

@test "librexgettext fails on subshell flag descriptions" {
	librexgettext fixtures/librexgettext/$BATS_TEST_NAME.sh >/dev/null 2>$tmpdir/stderr || status=$?

	[[ $status != 0 ]]
	[[ "$(sed 1q $tmpdir/stderr)" == "fixtures/librexgettext/$BATS_TEST_NAME.sh:5-6:"* ]]
}

@test "librexgettext doesnt keep failing" {
	librexgettext some_file_that_doesnt_exist >$tmpdir/stdout 2>$tmpdir/stderr || status=$?

	[[ $status != 0 ]]
	assert_file_empty $tmpdir/stdout
	[[ "$(wc -l <$tmpdir/stderr)" == 1 ]]
}

@test "librexgettext handles multiple files" {
	librexgettext fixtures/librexgettext/combine1.sh fixtures/librexgettext/combine2.sh >$tmpdir/actual.pot 2>$tmpdir/stderr
	assert_file_empty $tmpdir/stderr
	diff -u fixtures/librexgettext/combine.pot $tmpdir/actual.pot
}
